@@ -8,7 +8,7 @@ package Tickit;
 use strict;
 use warnings;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use IO::Handle;
 
@@ -24,18 +24,47 @@ C<Tickit> - Terminal Interface Construction KIT
 =head1 SYNOPSIS
 
  use Tickit;
+ use Tickit::Widget::Box;
+ use Tickit::Widget::Static;
 
  my $tickit = Tickit->new;
 
- # Create some widgets
- # ...
-
- $tickit->set_root_widget( $rootwidget );
+ my $box = Tickit::Widget::Box->new(
+    h_border => 4,
+    v_border => 2,
+    bg       => "green",
+    child    => Tickit::Widget::Static->new(
+       text     => "Hello, world!",
+       bg       => "black",
+       align    => "centre",
+       valign   => "middle",
+    ),
+ );
 
+ $tickit->set_root_widget( $box );
  $tickit->run;
 
 =head1 DESCRIPTION
 
+C<Tickit> is a high-level toolkit for creating full-screen terminal-based
+interactive programs. It allows programs to be written in an abstracted way,
+working with a tree of widget objects, to represent the layout of the
+interface and implement its behaviours.
+
+Its supported terminal features includes a rich set of rendering attributes
+(bold, underline, italic, 256-colours, etc), support for mouse including wheel
+and position events above the 224th column and arbitrary modified key input
+via F<libtermkey> (all of these will require a supporting terminal as well).
+It also supports having multiple instances and non-blocking or asynchronous
+control.
+
+At the current version, this is a Perl distribution which contains some XS
+utility code, and depends on a number of other XS modules to provide the
+remaining terminal behaviours. Work is in progress at porting the lower level
+parts into a standalone C library, with the intention being that eventually
+this distribution will become an XS wrapper for that C library. Development
+releases may appear on CPAN that include the C library and XS wrappings of it.
+
 =cut
 
 =head1 CONSTRUCTOR
