@@ -8,7 +8,7 @@ package Tickit::Term;
 use strict;
 use warnings;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Encode qw( find_encoding );
 use Term::Size;
@@ -125,10 +125,12 @@ event.
 
 Optional. Event handler function for when a mouse button is pressed or
 released, or the cursor dragged with a button pressed. Will be passed the
-C<Tickit::Term> instance, a string indicating C<press>, C<drag> or C<release>,
-the button number, and the 0-based line and column index.
+C<Tickit::Term> instance, a string indicating C<press>, C<drag>, C<release> or
+C<wheel>, the button number or wheel direction, and the 0-based line and
+column index. For C<wheel> events, the direction will be one of C<up> or
+C<down>.
 
- $on_mouse->( $term, $ev, $button, $line, $col )
+ $on_mouse->( $term, $ev, $button_dir, $line, $col )
 
 =back
 
@@ -445,6 +447,8 @@ sub _make_sgr_rv     { $_[1] ? 7 : 27 }
 sub _make_sgr_strike { $_[1] ? 9 : 29 }
 sub _make_sgr_af     { $_[1] ? $_[1]+10 : 10 }
 
+=head2 $term->chpen( $pen )
+
 =head2 $term->chpen( %attrs )
 
 Changes the current pen attributes to those given. Any attribute whose value
@@ -457,7 +461,7 @@ For details of the supported pen attributes, see L<Tickit::Pen>.
 sub chpen
 {
    my $self = shift;
-   my %new = @_;
+   my %new = ( @_ == 1 ) ? shift->getattrs : @_;
 
    my $pen = $self->{pen};
 
@@ -487,6 +491,8 @@ sub chpen
    }
 }
 
+=head2 $term->setpen( $pen )
+
 =head2 $term->setpen( %attrs )
 
 Similar to C<chpen>, but completely defines the state of the terminal pen. Any
@@ -497,7 +503,7 @@ attribute not given will be reset to its default value.
 sub setpen
 {
    my $self = shift;
-   my %new = @_;
+   my %new = ( @_ == 1 ) ? shift->getattrs : @_;
 
    $self->chpen( map { $_ => $new{$_} } @Tickit::Pen::ALL_ATTRS );
 }
@@ -685,6 +691,10 @@ sub _got_key
    elsif( $key->type_is_mouse ) {
       my ( $ev, $button, $line, $col ) = $termkey->interpret_mouse( $key );
       my $evname = (qw( * press drag release ))[$ev];
+      if( $button > 3 ) {
+         $evname = "wheel";
+         $button = (qw( up down ))[$button - 4] or return;
+      }
       $self->{on_mouse}->( $self, $evname, $button, $line - 1, $col - 1 ) if $self->{on_mouse};
    }
    else {
