@@ -3,7 +3,7 @@ package Tickit::Test::MockTerm;
 use strict;
 use warnings;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub new
 {
@@ -278,7 +278,7 @@ sub _scroll_lines
 sub chpen
 {
    my $self = shift;
-   my %attrs = @_;
+   my %attrs = ( @_ == 1 ) ? shift->getattrs : @_;
 
    $self->{pen}{$_} = $attrs{$_} for keys %attrs;
 
@@ -288,7 +288,7 @@ sub chpen
 sub setpen
 {
    my $self = shift;
-   my %attrs = @_;
+   my %attrs = ( @_ == 1 ) ? shift->getattrs : @_;
    $self->chpen( map { $_ => $attrs{$_} } @Tickit::Pen::ALL_ATTRS );
 }
 
