@@ -7,9 +7,8 @@ package Tickit::WidgetRole::Alignable;
 
 use strict;
 use warnings;
-use base qw( Tickit::WidgetRole );
 
-our $VERSION = '0.29_002';
+our $VERSION = '0.16';
 
 use Carp;
 
@@ -31,7 +30,7 @@ to implement alignment of content within a possibly-larger space.
 The following methods are provided parametrically on the caller package when
 the module is imported by
 
- use Tickit::WidgetRole::Alignable name => NAME, style => STYLE, reshape => RESHAPE
+ use Tickit::WidgetRole::Alignable name => NAME, style => STYLE
 
 The parameters are
 
@@ -48,12 +47,6 @@ Optional. The direction, horizontal or vertical, that the alignment
 represents. Used to parse symbolic names into fractions. Defaults to C<'h'> if
 not provided.
 
-=item reshape => BOOL
-
-Optional. If true, the widget will be reshaped after the value has been set by
-calling the C<reshape> method. If false or absent then it will just be redrawn
-by calling C<redraw>.
-
 =back
 
 =cut
@@ -63,20 +56,18 @@ my %symbolics = (
    v => { top  => 0.0, middle => 0.5, bottom => 1.0 },
 );
 
-sub export_subs_for
+sub import
 {
-   my $class = shift;
+   my $pkg = caller;
    shift;
    my %args = @_;
 
    my $name = $args{name} || "align";
    my $dir  = $args{dir}  || "h";
 
-   my $post_set_method = $args{reshape} ? "reshape" : "redraw";
-
    my $symbolics = $symbolics{$dir} or croak "Unrecognised dir - $dir";
 
-   return {
+   my %subs = (
       "$name" => sub {
          my $self = shift;
          return $self->{$name};
@@ -90,7 +81,7 @@ sub export_subs_for
 
          $self->{$name} = $align;
 
-         $self->$post_set_method;
+         $self->redraw;
       },
 
       "_${name}_allocation" => sub {
@@ -99,7 +90,10 @@ sub export_subs_for
 
          return align( $value, $total, $self->$name );
       },
-   };
+   );
+
+   no strict 'refs';
+   *{"${pkg}::$_"} = $subs{$_} for keys %subs;
 }
 
 =head2 $align = $widget->NAME
